"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
function _react() {
  const data = _interopRequireDefault(require("react"));
  _react = function _react() {
    return data;
  };
  return data;
}
function _icons() {
  const data = require("@ant-design/icons");
  _icons = function _icons() {
    return data;
  };
  return data;
}
function _css() {
  const data = require("@emotion/css");
  _css = function _css() {
    return data;
  };
  return data;
}
function _client() {
  const data = require("@nocobase/client");
  _client = function _client() {
    return data;
  };
  return data;
}
var _ = require(".");
var _FlowContext = require("../FlowContext");
var _locale = require("../locale");
var _variable = require("../variable");
var _style = require("../style");
var _Branch = require("../Branch");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function findOption(options, paths) {
  let current = options;
  for (let i = 0; i < paths.length; i++) {
    const path = paths[i];
    const option = current.find(item => item.value === path);
    if (!option) {
      return null;
    }
    if (option.children) {
      current = option.children;
    }
  }
  return current;
}
var _default = {
  title: `{{t("Loop", { ns: "${_locale.NAMESPACE}" })}}`,
  type: 'loop',
  group: 'control',
  description: `{{t("By using a loop node, you can perform the same operation on multiple sets of data. The source of these sets can be either multiple records from a query node or multiple associated records of a single record. Loop node can also be used for iterating a certain number of times or for looping through each character in a string. However, excessive looping may cause performance issues, so use with caution.", { ns: "${_locale.NAMESPACE}" })}}`,
  fieldset: {
    target: {
      type: 'string',
      title: `{{t("Loop target", { ns: "${_locale.NAMESPACE}" })}}`,
      description: `{{t("A single number will be treated as a loop count, a single string will be treated as an array of characters, and other non-array values will be converted to arrays. The loop node ends when the loop count is reached, or when the array loop is completed. You can also add condition nodes to the loop to terminate it.", { ns: "${_locale.NAMESPACE}" })}}`,
      'x-decorator': 'FormItem',
      'x-component': 'Variable.Input',
      'x-component-props': {
        scope: '{{useWorkflowVariableOptions}}',
        useTypedConstant: ['string', 'number', 'null']
      },
      required: true
    }
  },
  view: {},
  render: function Renderer(data) {
    var _entry$branchIndex;
    const _useFlowContext = (0, _FlowContext.useFlowContext)(),
      nodes = _useFlowContext.nodes;
    const entry = nodes.find(node => node.upstreamId === data.id && node.branchIndex != null);
    return _react().default.createElement(_.NodeDefaultView, {
      data: data
    }, _react().default.createElement("div", {
      className: (0, _css().cx)(_style.nodeSubtreeClass)
    }, _react().default.createElement("div", {
      className: (0, _css().cx)(_style.branchBlockClass, (0, _css().css)`
                padding-left: 20em;
              `)
    }, _react().default.createElement(_Branch.Branch, {
      from: data,
      entry: entry,
      branchIndex: (_entry$branchIndex = entry === null || entry === void 0 ? void 0 : entry.branchIndex) !== null && _entry$branchIndex !== void 0 ? _entry$branchIndex : 0
    }), _react().default.createElement("div", {
      className: (0, _css().cx)(_style.branchClass)
    }, _react().default.createElement("div", {
      className: "workflow-branch-lines"
    }), _react().default.createElement("div", {
      className: (0, _css().cx)(_style.addButtonClass, (0, _css().css)`
                    display: flex;
                    justify-content: center;
                    align-items: center;
                    position: absolute;
                    top: 50%;
                    transform: translateY(-50%);
                    width: 2em;
                    height: 6em;
                  `)
    }, _react().default.createElement(_icons().ArrowUpOutlined, {
      className: (0, _css().css)`
                    background-color: #f0f2f5;
                  `
    })))), _react().default.createElement("div", {
      className: (0, _css().css)`
              position: relative;
              height: 2em;
            `
    })));
  },
  scope: {
    useWorkflowVariableOptions: _variable.useWorkflowVariableOptions
  },
  components: {},
  useScopeVariables(node, options) {
    const compile = (0, _client().useCompile)();
    const target = node.config.target;
    if (!target) {
      return null;
    }
    // const { workflow } = useFlowContext();
    // const current = useNodeContext();
    // const upstreams = useAvailableUpstreams(current);
    // find target data model by path described in `config.target`
    // 1. get options from $context/$jobsMapByNodeId
    // 2. route to sub-options and use as loop target options
    const targetOption = {
      key: 'item',
      value: 'item',
      label: (0, _locale.lang)('Loop target')
    };
    if (typeof target === 'string' && target.startsWith('{{') && target.endsWith('}}')) {
      const paths = target.slice(2, -2).split('.').map(path => path.trim());
      const targetOptions = [_variable.nodesOptions, _variable.triggerOptions].map(item => {
        const opts = typeof item.useOptions === 'function' ? item.useOptions(options).filter(Boolean) : null;
        return {
          label: compile(item.title),
          value: item.value,
          key: item.value,
          children: compile(opts),
          disabled: opts && !opts.length
        };
      });
      targetOption.children = findOption(targetOptions, paths);
    }
    return [targetOption, {
      key: 'index',
      value: 'index',
      label: (0, _locale.lang)('Loop index')
    }, {
      key: 'length',
      value: 'length',
      label: (0, _locale.lang)('Loop length')
    }];
  }
};
exports.default = _default;